@@ -4,12 +4,16 @@
 #' [show_models]. It focus on generating forest plot easily
 #' and flexibly.
 #'
-#' @inheritParams ezcox
 #' @inheritParams show_models
+#' @inheritParams ezcox
 #' @param vars_to_show default is `NULL`, show all variables
 #' (including controls). You can use this to choose variables
 #' to show, but remember, the models have not been changed.
 #' @param add_caption if `TRUE`, add caption to the plot.
+#' @param point_size size of point.
+#' @param point_shape shape value of point.
+#' @param color color for point and segment.
+#' @param banded if `TRUE` (default), create banded background color.
 #'
 #' @return a `ggplot` object
 #' @export
@@ -34,6 +38,10 @@ show_forest <- function(data, covariates, controls = NULL,
                         vars_to_show = NULL,
                         drop_controls = FALSE,
                         add_caption = TRUE,
+                        point_size = 3,
+                        point_shape = 15,
+                        color = "red",
+                        banded = TRUE,
                         headings = list(variable = "Variable", n = "N", measure = "Hazard ratio", ci = NULL, p = "p"),
                         model_dir = file.path(tempdir(), "ezcox"),
                         verbose = TRUE,
@@ -53,6 +61,9 @@ show_forest <- function(data, covariates, controls = NULL,
     merge_models = merge_models,
     drop_controls = drop_controls,
     headings = headings,
+    format_options = forestmodel::forest_model_format_options(
+      point_size  = point_size, shape = point_shape, color = color, banded = banded
+    ),
     ...
   )
 
